'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _messagingApiMessenger = require('messaging-api-messenger');

var _axiosError = require('axios-error');

var _axiosError2 = _interopRequireDefault(_axiosError);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function handleError(err) {
  const { error } = err.response.data;
  const msg = `Messenger API - ${error.code} ${error.type} ${error.message}`;
  throw new _axiosError2.default(msg, err);
}

class FacebookClient extends _messagingApiMessenger.MessengerClient {

  constructor(accessToken, version = '2.11') {
    super(accessToken, version);

    _initialiseProps.call(this);
  }

}
exports.default = FacebookClient;

FacebookClient.connect = (accessToken, version = '2.11') => new FacebookClient(accessToken, version);

var _initialiseProps = function () {
  this.sendPrivateReply = (objectId, message, { access_token: customAccessToken } = {}) => this._axios.post(`/${objectId}/private_replies?access_token=${customAccessToken || this._accessToken}`, {
    message
  }).then(res => res.data, handleError);

  this.sendComment = (objectId, message, { access_token: customAccessToken } = {}) => this._axios.post(`/${objectId}/comments?access_token=${customAccessToken || this._accessToken}`, {
    message
  }).then(res => res.data, handleError);
};