'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _bottender = require('bottender');

var _warning = require('warning');

var _warning2 = _interopRequireDefault(_warning);

var _FacebookContext = require('./FacebookContext');

var _FacebookContext2 = _interopRequireDefault(_FacebookContext);

var _FacebookEvent = require('./FacebookEvent');

var _FacebookEvent2 = _interopRequireDefault(_FacebookEvent);

var _FacebookClient = require('./FacebookClient');

var _FacebookClient2 = _interopRequireDefault(_FacebookClient);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class FacebookConnector extends _bottender.MessengerConnector {

  constructor({
    accessToken,
    appSecret,
    client,
    mapPageToAccessToken
  }) {
    const _client = client || _FacebookClient2.default.connect(accessToken || '');
    super({ accessToken, appSecret, client: _client, mapPageToAccessToken });
  }

  // FIXME: should not rely on private method
  _getRawEventsFromRequest(body) {
    if (body.entry) {
      const { entry } = body;

      return entry.map(ent => {
        if (ent.messaging) {
          return ent.messaging[0];
        }

        if (ent.standby) {
          return ent.standby[0];
        }

        // Patch For Facebook Start
        if (ent.changes) {
          return ent.changes[0];
        }
        // Patch For Facebook End

        return null;
      }).filter(event => event != null);
    }

    return [body];
  }

  mapRequestToEvents(body) {
    const rawEvents = this._getRawEventsFromRequest(body);
    const isStandby = this._isStandby(body);
    let pageId = null;
    if (body.object === 'page' && body.entry && body.entry[0]) {
      pageId = body.entry[0].id;
    }
    return rawEvents.map(event => new _FacebookEvent2.default(event, { isStandby, pageId }));
  }

  async createContext({
    event,
    session,
    initialState
  }) {
    let customAccessToken;

    if (this._mapPageToAccessToken) {
      const { rawEvent } = event;
      let pageId = null;

      if (event.isFeed) {
        pageId = rawEvent.value.post_id.split('_')[0];
      } else if (event.isEcho && rawEvent.sender) {
        pageId = rawEvent.sender.id;
      } else if (rawEvent.recipient) {
        pageId = rawEvent.recipient.id;
      }

      if (!pageId) {
        (0, _warning2.default)(false, 'Could not find pageId from request body.');
      } else {
        customAccessToken = await this._mapPageToAccessToken(pageId);
      }
    }
    return new _FacebookContext2.default({
      client: this._client,
      event,
      session,
      initialState,
      customAccessToken
    });
  }
}
exports.default = FacebookConnector;