'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _bottender = require('bottender');

class FacebookEvent extends _bottender.MessengerEvent {
  constructor(rawEvent, options = {}) {
    super(rawEvent, options);
    this._pageId = options.pageId;
  }

  get isConversation() {
    return this.rawEvent.field === 'conversation';
  }

  get isFeed() {
    return this.rawEvent.field === 'feed';
  }

  get isStatus() {
    return this.isFeed && this.rawEvent.value.item === 'status';
  }

  get isStatusAdd() {
    return this.isStatus && this.rawEvent.value.verb === 'add';
  }

  get isStatusEdited() {
    return this.isStatus && this.rawEvent.value.verb === 'edited';
  }

  get status() {
    if (this.isStatus) {
      return this.rawEvent.value;
    }
    return null;
  }

  get isPost() {
    return this.isFeed && this.rawEvent.value.item === 'post';
  }

  get isPostRemove() {
    return this.isPost && this.rawEvent.value.verb === 'remove';
  }

  get post() {
    if (this.isPost) {
      return this.rawEvent.value;
    }
    return null;
  }

  get isComment() {
    return this.isFeed && this.rawEvent.value.item === 'comment';
  }

  get isCommentAdd() {
    return this.isComment && this.rawEvent.value.verb === 'add';
  }

  get isCommentEdited() {
    return this.isComment && this.rawEvent.value.verb === 'edited';
  }

  get isCommentRemove() {
    return this.isComment && this.rawEvent.value.verb === 'remove';
  }

  get comment() {
    if (this.isComment) {
      return this.rawEvent.value;
    }
    return null;
  }

  get isLike() {
    return this.isFeed && this.rawEvent.value.item === 'like';
  }

  get isLikeAdd() {
    return this.isLike && this.rawEvent.value.verb === 'add';
  }

  get isLikeRemove() {
    return this.isLike && this.rawEvent.value.verb === 'remove';
  }

  get like() {
    if (this.isLike) {
      return this.rawEvent.value;
    }
    return null;
  }

  get isReaction() {
    return this.isFeed && this.rawEvent.value.item === 'reaction';
  }

  get isReactionAdd() {
    return this.isReaction && this.rawEvent.value.verb === 'add';
  }

  get isReactionEdit() {
    return this.isReaction && this.rawEvent.value.verb === 'edit';
  }

  get isReactionRemove() {
    return this.isReaction && this.rawEvent.value.verb === 'remove';
  }

  get reaction() {
    if (this.isReaction) {
      return this.rawEvent.value;
    }
    return null;
  }

  get pageId() {
    return this._pageId || null;
  }

  get isSentByPage() {
    return this.rawEvent.value.from.id === this.pageId;
  }
}
exports.default = FacebookEvent;